# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_rotations_get200_response import ApiV1SecretRotationsGet200Response  # noqa: E501

class TestApiV1SecretRotationsGet200Response(unittest.TestCase):
    """ApiV1SecretRotationsGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretRotationsGet200Response:
        """Test ApiV1SecretRotationsGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretRotationsGet200Response`
        """
        model = ApiV1SecretRotationsGet200Response()  # noqa: E501
        if include_optional:
            return ApiV1SecretRotationsGet200Response(
                secret_rotations = [
                    infisicalapi_client.models._api_v1_secret_rotations_get_200_response_secret_rotations_inner._api_v1_secret_rotations_get_200_response_secretRotations_inner(
                        id = '', 
                        provider = '', 
                        secret_path = '', 
                        interval = 1.337, 
                        last_rotated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        status = '', 
                        status_message = '', 
                        encrypted_data = '', 
                        encrypted_data_iv = '', 
                        encrypted_data_tag = '', 
                        algorithm = '', 
                        key_encoding = '', 
                        env_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        environment = infisicalapi_client.models._api_v1_secret_approvals_get_200_response_approvals_inner_environment._api_v1_secret_approvals_get_200_response_approvals_inner_environment(
                            id = '', 
                            name = '', 
                            slug = '', ), 
                        outputs = [
                            infisicalapi_client.models._api_v1_secret_rotations_get_200_response_secret_rotations_inner_outputs_inner._api_v1_secret_rotations_get_200_response_secretRotations_inner_outputs_inner(
                                key = '', 
                                secret = infisicalapi_client.models._api_v1_secret_rotations_get_200_response_secret_rotations_inner_outputs_inner_secret._api_v1_secret_rotations_get_200_response_secretRotations_inner_outputs_inner_secret(
                                    secret_key = '', 
                                    id = '', 
                                    version = 1.337, ), )
                            ], )
                    ]
            )
        else:
            return ApiV1SecretRotationsGet200Response(
                secret_rotations = [
                    infisicalapi_client.models._api_v1_secret_rotations_get_200_response_secret_rotations_inner._api_v1_secret_rotations_get_200_response_secretRotations_inner(
                        id = '', 
                        provider = '', 
                        secret_path = '', 
                        interval = 1.337, 
                        last_rotated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        status = '', 
                        status_message = '', 
                        encrypted_data = '', 
                        encrypted_data_iv = '', 
                        encrypted_data_tag = '', 
                        algorithm = '', 
                        key_encoding = '', 
                        env_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        environment = infisicalapi_client.models._api_v1_secret_approvals_get_200_response_approvals_inner_environment._api_v1_secret_approvals_get_200_response_approvals_inner_environment(
                            id = '', 
                            name = '', 
                            slug = '', ), 
                        outputs = [
                            infisicalapi_client.models._api_v1_secret_rotations_get_200_response_secret_rotations_inner_outputs_inner._api_v1_secret_rotations_get_200_response_secretRotations_inner_outputs_inner(
                                key = '', 
                                secret = infisicalapi_client.models._api_v1_secret_rotations_get_200_response_secret_rotations_inner_outputs_inner_secret._api_v1_secret_rotations_get_200_response_secretRotations_inner_outputs_inner_secret(
                                    secret_key = '', 
                                    id = '', 
                                    version = 1.337, ), )
                            ], )
                    ],
        )
        """

    def testApiV1SecretRotationsGet200Response(self):
        """Test ApiV1SecretRotationsGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, conlist
from infisicalapi_client.models.api_v1_secret_approval_requests_get200_response_approvals_inner_committer_user import ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitterUser

class ApiV1SecretApprovalRequestsIdGet200ResponseApprovalPolicy(BaseModel):
    """
    ApiV1SecretApprovalRequestsIdGet200ResponseApprovalPolicy
    """
    id: StrictStr = Field(...)
    name: StrictStr = Field(...)
    approvals: Union[StrictFloat, StrictInt] = Field(...)
    approvers: conlist(ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitterUser) = Field(...)
    secret_path: Optional[StrictStr] = Field(default=None, alias="secretPath")
    enforcement_level: StrictStr = Field(default=..., alias="enforcementLevel")
    __properties = ["id", "name", "approvals", "approvers", "secretPath", "enforcementLevel"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SecretApprovalRequestsIdGet200ResponseApprovalPolicy:
        """Create an instance of ApiV1SecretApprovalRequestsIdGet200ResponseApprovalPolicy from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in approvers (list)
        _items = []
        if self.approvers:
            for _item in self.approvers:
                if _item:
                    _items.append(_item.to_dict())
            _dict['approvers'] = _items
        # set to None if secret_path (nullable) is None
        # and __fields_set__ contains the field
        if self.secret_path is None and "secret_path" in self.__fields_set__:
            _dict['secretPath'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SecretApprovalRequestsIdGet200ResponseApprovalPolicy:
        """Create an instance of ApiV1SecretApprovalRequestsIdGet200ResponseApprovalPolicy from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SecretApprovalRequestsIdGet200ResponseApprovalPolicy.parse_obj(obj)

        _obj = ApiV1SecretApprovalRequestsIdGet200ResponseApprovalPolicy.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "approvals": obj.get("approvals"),
            "approvers": [ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitterUser.from_dict(_item) for _item in obj.get("approvers")] if obj.get("approvers") is not None else None,
            "secret_path": obj.get("secretPath"),
            "enforcement_level": obj.get("enforcementLevel")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, List, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, conlist
from infisicalapi_client.models.api_v2_service_token_get200_response_user import ApiV2ServiceTokenGet200ResponseUser

class ApiV2ServiceTokenGet200Response(BaseModel):
    """
    ApiV2ServiceTokenGet200Response
    """
    id: StrictStr = Field(...)
    name: StrictStr = Field(...)
    scopes: Optional[Any] = None
    permissions: conlist(StrictStr) = Field(...)
    last_used: Optional[datetime] = Field(default=None, alias="lastUsed")
    expires_at: Optional[datetime] = Field(default=None, alias="expiresAt")
    secret_hash: StrictStr = Field(default=..., alias="secretHash")
    encrypted_key: Optional[StrictStr] = Field(default=None, alias="encryptedKey")
    iv: Optional[StrictStr] = None
    tag: Optional[StrictStr] = None
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    created_by: StrictStr = Field(default=..., alias="createdBy")
    project_id: StrictStr = Field(default=..., alias="projectId")
    workspace: StrictStr = Field(...)
    user: ApiV2ServiceTokenGet200ResponseUser = Field(...)
    id: StrictStr = Field(default=..., alias="_id")
    v: Optional[Union[StrictFloat, StrictInt]] = Field(default=0, alias="__v")
    __properties = ["id", "name", "scopes", "permissions", "lastUsed", "expiresAt", "secretHash", "encryptedKey", "iv", "tag", "createdAt", "updatedAt", "createdBy", "projectId", "workspace", "user", "_id", "__v"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV2ServiceTokenGet200Response:
        """Create an instance of ApiV2ServiceTokenGet200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        # set to None if scopes (nullable) is None
        # and __fields_set__ contains the field
        if self.scopes is None and "scopes" in self.__fields_set__:
            _dict['scopes'] = None

        # set to None if last_used (nullable) is None
        # and __fields_set__ contains the field
        if self.last_used is None and "last_used" in self.__fields_set__:
            _dict['lastUsed'] = None

        # set to None if expires_at (nullable) is None
        # and __fields_set__ contains the field
        if self.expires_at is None and "expires_at" in self.__fields_set__:
            _dict['expiresAt'] = None

        # set to None if encrypted_key (nullable) is None
        # and __fields_set__ contains the field
        if self.encrypted_key is None and "encrypted_key" in self.__fields_set__:
            _dict['encryptedKey'] = None

        # set to None if iv (nullable) is None
        # and __fields_set__ contains the field
        if self.iv is None and "iv" in self.__fields_set__:
            _dict['iv'] = None

        # set to None if tag (nullable) is None
        # and __fields_set__ contains the field
        if self.tag is None and "tag" in self.__fields_set__:
            _dict['tag'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV2ServiceTokenGet200Response:
        """Create an instance of ApiV2ServiceTokenGet200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV2ServiceTokenGet200Response.parse_obj(obj)

        _obj = ApiV2ServiceTokenGet200Response.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "scopes": obj.get("scopes"),
            "permissions": obj.get("permissions"),
            "last_used": obj.get("lastUsed"),
            "expires_at": obj.get("expiresAt"),
            "secret_hash": obj.get("secretHash"),
            "encrypted_key": obj.get("encryptedKey"),
            "iv": obj.get("iv"),
            "tag": obj.get("tag"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "created_by": obj.get("createdBy"),
            "project_id": obj.get("projectId"),
            "workspace": obj.get("workspace"),
            "user": ApiV2ServiceTokenGet200ResponseUser.from_dict(obj.get("user")) if obj.get("user") is not None else None,
            "id": obj.get("_id"),
            "v": obj.get("__v") if obj.get("__v") is not None else 0
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class ApiV1ExternalKmsGet200ResponseExternalKmsListInnerExternalKms(BaseModel):
    """
    ApiV1ExternalKmsGet200ResponseExternalKmsListInnerExternalKms
    """
    provider: StrictStr = Field(...)
    status: Optional[StrictStr] = None
    status_details: Optional[StrictStr] = Field(default=None, alias="statusDetails")
    __properties = ["provider", "status", "statusDetails"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1ExternalKmsGet200ResponseExternalKmsListInnerExternalKms:
        """Create an instance of ApiV1ExternalKmsGet200ResponseExternalKmsListInnerExternalKms from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if status (nullable) is None
        # and __fields_set__ contains the field
        if self.status is None and "status" in self.__fields_set__:
            _dict['status'] = None

        # set to None if status_details (nullable) is None
        # and __fields_set__ contains the field
        if self.status_details is None and "status_details" in self.__fields_set__:
            _dict['statusDetails'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1ExternalKmsGet200ResponseExternalKmsListInnerExternalKms:
        """Create an instance of ApiV1ExternalKmsGet200ResponseExternalKmsListInnerExternalKms from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1ExternalKmsGet200ResponseExternalKmsListInnerExternalKms.parse_obj(obj)

        _obj = ApiV1ExternalKmsGet200ResponseExternalKmsListInnerExternalKms.parse_obj({
            "provider": obj.get("provider"),
            "status": obj.get("status"),
            "status_details": obj.get("statusDetails")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr

class ApiV1FoldersGet200ResponseFoldersInner(BaseModel):
    """
    ApiV1FoldersGet200ResponseFoldersInner
    """
    id: StrictStr = Field(...)
    name: StrictStr = Field(...)
    version: Optional[Union[StrictFloat, StrictInt]] = 1
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    env_id: StrictStr = Field(default=..., alias="envId")
    parent_id: Optional[StrictStr] = Field(default=None, alias="parentId")
    is_reserved: Optional[StrictBool] = Field(default=False, alias="isReserved")
    __properties = ["id", "name", "version", "createdAt", "updatedAt", "envId", "parentId", "isReserved"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1FoldersGet200ResponseFoldersInner:
        """Create an instance of ApiV1FoldersGet200ResponseFoldersInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if version (nullable) is None
        # and __fields_set__ contains the field
        if self.version is None and "version" in self.__fields_set__:
            _dict['version'] = None

        # set to None if parent_id (nullable) is None
        # and __fields_set__ contains the field
        if self.parent_id is None and "parent_id" in self.__fields_set__:
            _dict['parentId'] = None

        # set to None if is_reserved (nullable) is None
        # and __fields_set__ contains the field
        if self.is_reserved is None and "is_reserved" in self.__fields_set__:
            _dict['isReserved'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1FoldersGet200ResponseFoldersInner:
        """Create an instance of ApiV1FoldersGet200ResponseFoldersInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1FoldersGet200ResponseFoldersInner.parse_obj(obj)

        _obj = ApiV1FoldersGet200ResponseFoldersInner.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "version": obj.get("version") if obj.get("version") is not None else 1,
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "env_id": obj.get("envId"),
            "parent_id": obj.get("parentId"),
            "is_reserved": obj.get("isReserved") if obj.get("isReserved") is not None else False
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

class ApiV1PkiCaPost200ResponseCa(BaseModel):
    """
    ApiV1PkiCaPost200ResponseCa
    """
    id: StrictStr = Field(...)
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    parent_ca_id: Optional[StrictStr] = Field(default=None, alias="parentCaId")
    project_id: StrictStr = Field(default=..., alias="projectId")
    type: StrictStr = Field(...)
    status: StrictStr = Field(...)
    friendly_name: StrictStr = Field(default=..., alias="friendlyName")
    organization: StrictStr = Field(...)
    ou: StrictStr = Field(...)
    country: StrictStr = Field(...)
    province: StrictStr = Field(...)
    locality: StrictStr = Field(...)
    common_name: StrictStr = Field(default=..., alias="commonName")
    dn: StrictStr = Field(...)
    serial_number: Optional[StrictStr] = Field(default=None, alias="serialNumber")
    max_path_length: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maxPathLength")
    key_algorithm: StrictStr = Field(default=..., alias="keyAlgorithm")
    not_before: Optional[datetime] = Field(default=None, alias="notBefore")
    not_after: Optional[datetime] = Field(default=None, alias="notAfter")
    __properties = ["id", "createdAt", "updatedAt", "parentCaId", "projectId", "type", "status", "friendlyName", "organization", "ou", "country", "province", "locality", "commonName", "dn", "serialNumber", "maxPathLength", "keyAlgorithm", "notBefore", "notAfter"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1PkiCaPost200ResponseCa:
        """Create an instance of ApiV1PkiCaPost200ResponseCa from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if parent_ca_id (nullable) is None
        # and __fields_set__ contains the field
        if self.parent_ca_id is None and "parent_ca_id" in self.__fields_set__:
            _dict['parentCaId'] = None

        # set to None if serial_number (nullable) is None
        # and __fields_set__ contains the field
        if self.serial_number is None and "serial_number" in self.__fields_set__:
            _dict['serialNumber'] = None

        # set to None if max_path_length (nullable) is None
        # and __fields_set__ contains the field
        if self.max_path_length is None and "max_path_length" in self.__fields_set__:
            _dict['maxPathLength'] = None

        # set to None if not_before (nullable) is None
        # and __fields_set__ contains the field
        if self.not_before is None and "not_before" in self.__fields_set__:
            _dict['notBefore'] = None

        # set to None if not_after (nullable) is None
        # and __fields_set__ contains the field
        if self.not_after is None and "not_after" in self.__fields_set__:
            _dict['notAfter'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1PkiCaPost200ResponseCa:
        """Create an instance of ApiV1PkiCaPost200ResponseCa from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1PkiCaPost200ResponseCa.parse_obj(obj)

        _obj = ApiV1PkiCaPost200ResponseCa.parse_obj({
            "id": obj.get("id"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "parent_ca_id": obj.get("parentCaId"),
            "project_id": obj.get("projectId"),
            "type": obj.get("type"),
            "status": obj.get("status"),
            "friendly_name": obj.get("friendlyName"),
            "organization": obj.get("organization"),
            "ou": obj.get("ou"),
            "country": obj.get("country"),
            "province": obj.get("province"),
            "locality": obj.get("locality"),
            "common_name": obj.get("commonName"),
            "dn": obj.get("dn"),
            "serial_number": obj.get("serialNumber"),
            "max_path_length": obj.get("maxPathLength"),
            "key_algorithm": obj.get("keyAlgorithm"),
            "not_before": obj.get("notBefore"),
            "not_after": obj.get("notAfter")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_sso_config_patch_request import ApiV1SsoConfigPatchRequest  # noqa: E501

class TestApiV1SsoConfigPatchRequest(unittest.TestCase):
    """ApiV1SsoConfigPatchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SsoConfigPatchRequest:
        """Test ApiV1SsoConfigPatchRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SsoConfigPatchRequest`
        """
        model = ApiV1SsoConfigPatchRequest()  # noqa: E501
        if include_optional:
            return ApiV1SsoConfigPatchRequest(
                auth_provider = 'okta-saml',
                is_active = True,
                entry_point = '',
                issuer = '',
                cert = '',
                organization_id = ''
            )
        else:
            return ApiV1SsoConfigPatchRequest(
                organization_id = '',
        )
        """

    def testApiV1SsoConfigPatchRequest(self):
        """Test ApiV1SsoConfigPatchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist

class ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner(BaseModel):
    """
    ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner
    """
    id: StrictStr = Field(...)
    description: Optional[StrictStr] = None
    start_line: Optional[StrictStr] = Field(default=None, alias="startLine")
    end_line: Optional[StrictStr] = Field(default=None, alias="endLine")
    start_column: Optional[StrictStr] = Field(default=None, alias="startColumn")
    end_column: Optional[StrictStr] = Field(default=None, alias="endColumn")
    file: Optional[StrictStr] = None
    symlink_file: Optional[StrictStr] = Field(default=None, alias="symlinkFile")
    commit: Optional[StrictStr] = None
    entropy: Optional[StrictStr] = None
    author: Optional[StrictStr] = None
    email: Optional[StrictStr] = None
    var_date: Optional[StrictStr] = Field(default=None, alias="date")
    message: Optional[StrictStr] = None
    tags: Optional[conlist(StrictStr)] = None
    rule_id: Optional[StrictStr] = Field(default=None, alias="ruleID")
    fingerprint: Optional[StrictStr] = None
    finger_print_without_commit_id: Optional[StrictStr] = Field(default=None, alias="fingerPrintWithoutCommitId")
    is_false_positive: Optional[StrictBool] = Field(default=False, alias="isFalsePositive")
    is_resolved: Optional[StrictBool] = Field(default=False, alias="isResolved")
    risk_owner: Optional[StrictStr] = Field(default=None, alias="riskOwner")
    installation_id: StrictStr = Field(default=..., alias="installationId")
    repository_id: Optional[StrictStr] = Field(default=None, alias="repositoryId")
    repository_link: Optional[StrictStr] = Field(default=None, alias="repositoryLink")
    repository_full_name: Optional[StrictStr] = Field(default=None, alias="repositoryFullName")
    pusher_name: Optional[StrictStr] = Field(default=None, alias="pusherName")
    pusher_email: Optional[StrictStr] = Field(default=None, alias="pusherEmail")
    status: Optional[StrictStr] = None
    org_id: StrictStr = Field(default=..., alias="orgId")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    __properties = ["id", "description", "startLine", "endLine", "startColumn", "endColumn", "file", "symlinkFile", "commit", "entropy", "author", "email", "date", "message", "tags", "ruleID", "fingerprint", "fingerPrintWithoutCommitId", "isFalsePositive", "isResolved", "riskOwner", "installationId", "repositoryId", "repositoryLink", "repositoryFullName", "pusherName", "pusherEmail", "status", "orgId", "createdAt", "updatedAt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner:
        """Create an instance of ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict['description'] = None

        # set to None if start_line (nullable) is None
        # and __fields_set__ contains the field
        if self.start_line is None and "start_line" in self.__fields_set__:
            _dict['startLine'] = None

        # set to None if end_line (nullable) is None
        # and __fields_set__ contains the field
        if self.end_line is None and "end_line" in self.__fields_set__:
            _dict['endLine'] = None

        # set to None if start_column (nullable) is None
        # and __fields_set__ contains the field
        if self.start_column is None and "start_column" in self.__fields_set__:
            _dict['startColumn'] = None

        # set to None if end_column (nullable) is None
        # and __fields_set__ contains the field
        if self.end_column is None and "end_column" in self.__fields_set__:
            _dict['endColumn'] = None

        # set to None if file (nullable) is None
        # and __fields_set__ contains the field
        if self.file is None and "file" in self.__fields_set__:
            _dict['file'] = None

        # set to None if symlink_file (nullable) is None
        # and __fields_set__ contains the field
        if self.symlink_file is None and "symlink_file" in self.__fields_set__:
            _dict['symlinkFile'] = None

        # set to None if commit (nullable) is None
        # and __fields_set__ contains the field
        if self.commit is None and "commit" in self.__fields_set__:
            _dict['commit'] = None

        # set to None if entropy (nullable) is None
        # and __fields_set__ contains the field
        if self.entropy is None and "entropy" in self.__fields_set__:
            _dict['entropy'] = None

        # set to None if author (nullable) is None
        # and __fields_set__ contains the field
        if self.author is None and "author" in self.__fields_set__:
            _dict['author'] = None

        # set to None if email (nullable) is None
        # and __fields_set__ contains the field
        if self.email is None and "email" in self.__fields_set__:
            _dict['email'] = None

        # set to None if var_date (nullable) is None
        # and __fields_set__ contains the field
        if self.var_date is None and "var_date" in self.__fields_set__:
            _dict['date'] = None

        # set to None if message (nullable) is None
        # and __fields_set__ contains the field
        if self.message is None and "message" in self.__fields_set__:
            _dict['message'] = None

        # set to None if tags (nullable) is None
        # and __fields_set__ contains the field
        if self.tags is None and "tags" in self.__fields_set__:
            _dict['tags'] = None

        # set to None if rule_id (nullable) is None
        # and __fields_set__ contains the field
        if self.rule_id is None and "rule_id" in self.__fields_set__:
            _dict['ruleID'] = None

        # set to None if fingerprint (nullable) is None
        # and __fields_set__ contains the field
        if self.fingerprint is None and "fingerprint" in self.__fields_set__:
            _dict['fingerprint'] = None

        # set to None if finger_print_without_commit_id (nullable) is None
        # and __fields_set__ contains the field
        if self.finger_print_without_commit_id is None and "finger_print_without_commit_id" in self.__fields_set__:
            _dict['fingerPrintWithoutCommitId'] = None

        # set to None if is_false_positive (nullable) is None
        # and __fields_set__ contains the field
        if self.is_false_positive is None and "is_false_positive" in self.__fields_set__:
            _dict['isFalsePositive'] = None

        # set to None if is_resolved (nullable) is None
        # and __fields_set__ contains the field
        if self.is_resolved is None and "is_resolved" in self.__fields_set__:
            _dict['isResolved'] = None

        # set to None if risk_owner (nullable) is None
        # and __fields_set__ contains the field
        if self.risk_owner is None and "risk_owner" in self.__fields_set__:
            _dict['riskOwner'] = None

        # set to None if repository_id (nullable) is None
        # and __fields_set__ contains the field
        if self.repository_id is None and "repository_id" in self.__fields_set__:
            _dict['repositoryId'] = None

        # set to None if repository_link (nullable) is None
        # and __fields_set__ contains the field
        if self.repository_link is None and "repository_link" in self.__fields_set__:
            _dict['repositoryLink'] = None

        # set to None if repository_full_name (nullable) is None
        # and __fields_set__ contains the field
        if self.repository_full_name is None and "repository_full_name" in self.__fields_set__:
            _dict['repositoryFullName'] = None

        # set to None if pusher_name (nullable) is None
        # and __fields_set__ contains the field
        if self.pusher_name is None and "pusher_name" in self.__fields_set__:
            _dict['pusherName'] = None

        # set to None if pusher_email (nullable) is None
        # and __fields_set__ contains the field
        if self.pusher_email is None and "pusher_email" in self.__fields_set__:
            _dict['pusherEmail'] = None

        # set to None if status (nullable) is None
        # and __fields_set__ contains the field
        if self.status is None and "status" in self.__fields_set__:
            _dict['status'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner:
        """Create an instance of ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner.parse_obj(obj)

        _obj = ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner.parse_obj({
            "id": obj.get("id"),
            "description": obj.get("description"),
            "start_line": obj.get("startLine"),
            "end_line": obj.get("endLine"),
            "start_column": obj.get("startColumn"),
            "end_column": obj.get("endColumn"),
            "file": obj.get("file"),
            "symlink_file": obj.get("symlinkFile"),
            "commit": obj.get("commit"),
            "entropy": obj.get("entropy"),
            "author": obj.get("author"),
            "email": obj.get("email"),
            "var_date": obj.get("date"),
            "message": obj.get("message"),
            "tags": obj.get("tags"),
            "rule_id": obj.get("ruleID"),
            "fingerprint": obj.get("fingerprint"),
            "finger_print_without_commit_id": obj.get("fingerPrintWithoutCommitId"),
            "is_false_positive": obj.get("isFalsePositive") if obj.get("isFalsePositive") is not None else False,
            "is_resolved": obj.get("isResolved") if obj.get("isResolved") is not None else False,
            "risk_owner": obj.get("riskOwner"),
            "installation_id": obj.get("installationId"),
            "repository_id": obj.get("repositoryId"),
            "repository_link": obj.get("repositoryLink"),
            "repository_full_name": obj.get("repositoryFullName"),
            "pusher_name": obj.get("pusherName"),
            "pusher_email": obj.get("pusherEmail"),
            "status": obj.get("status"),
            "org_id": obj.get("orgId"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_password_email_password_reset_verify_post200_response_user import ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser  # noqa: E501

class TestApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser(unittest.TestCase):
    """ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser:
        """Test ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser`
        """
        model = ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser()  # noqa: E501
        if include_optional:
            return ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser(
                id = '',
                email = '',
                auth_methods = [
                    ''
                    ],
                super_admin = True,
                first_name = '',
                last_name = '',
                is_accepted = True,
                is_mfa_enabled = True,
                mfa_methods = [
                    ''
                    ],
                devices = None,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                is_ghost = True,
                username = '',
                is_email_verified = True,
                consecutive_failed_mfa_attempts = 1.337,
                is_locked = True,
                temporary_lock_date_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                consecutive_failed_password_attempts = 1.337
            )
        else:
            return ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser(
                id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                username = '',
        )
        """

    def testApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser(self):
        """Test ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime

from pydantic import BaseModel, Field, StrictStr

class ApiV1UserActionPost200ResponseUserAction(BaseModel):
    """
    ApiV1UserActionPost200ResponseUserAction
    """
    id: StrictStr = Field(...)
    action: StrictStr = Field(...)
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    user_id: StrictStr = Field(default=..., alias="userId")
    __properties = ["id", "action", "createdAt", "updatedAt", "userId"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1UserActionPost200ResponseUserAction:
        """Create an instance of ApiV1UserActionPost200ResponseUserAction from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1UserActionPost200ResponseUserAction:
        """Create an instance of ApiV1UserActionPost200ResponseUserAction from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1UserActionPost200ResponseUserAction.parse_obj(obj)

        _obj = ApiV1UserActionPost200ResponseUserAction.parse_obj({
            "id": obj.get("id"),
            "action": obj.get("action"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "user_id": obj.get("userId")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v2_organizations_organization_id_workspaces_get200_response_workspaces_inner_environments_inner import ApiV2OrganizationsOrganizationIdWorkspacesGet200ResponseWorkspacesInnerEnvironmentsInner  # noqa: E501

class TestApiV2OrganizationsOrganizationIdWorkspacesGet200ResponseWorkspacesInnerEnvironmentsInner(unittest.TestCase):
    """ApiV2OrganizationsOrganizationIdWorkspacesGet200ResponseWorkspacesInnerEnvironmentsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV2OrganizationsOrganizationIdWorkspacesGet200ResponseWorkspacesInnerEnvironmentsInner:
        """Test ApiV2OrganizationsOrganizationIdWorkspacesGet200ResponseWorkspacesInnerEnvironmentsInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV2OrganizationsOrganizationIdWorkspacesGet200ResponseWorkspacesInnerEnvironmentsInner`
        """
        model = ApiV2OrganizationsOrganizationIdWorkspacesGet200ResponseWorkspacesInnerEnvironmentsInner()  # noqa: E501
        if include_optional:
            return ApiV2OrganizationsOrganizationIdWorkspacesGet200ResponseWorkspacesInnerEnvironmentsInner(
                name = '',
                slug = ''
            )
        else:
            return ApiV2OrganizationsOrganizationIdWorkspacesGet200ResponseWorkspacesInnerEnvironmentsInner(
                name = '',
                slug = '',
        )
        """

    def testApiV2OrganizationsOrganizationIdWorkspacesGet200ResponseWorkspacesInnerEnvironmentsInner(self):
        """Test ApiV2OrganizationsOrganizationIdWorkspacesGet200ResponseWorkspacesInnerEnvironmentsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_external_kms_post_request_provider_inputs_credential import ApiV1ExternalKmsPostRequestProviderInputsCredential  # noqa: E501

class TestApiV1ExternalKmsPostRequestProviderInputsCredential(unittest.TestCase):
    """ApiV1ExternalKmsPostRequestProviderInputsCredential unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1ExternalKmsPostRequestProviderInputsCredential:
        """Test ApiV1ExternalKmsPostRequestProviderInputsCredential
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1ExternalKmsPostRequestProviderInputsCredential`
        """
        model = ApiV1ExternalKmsPostRequestProviderInputsCredential()  # noqa: E501
        if include_optional:
            return ApiV1ExternalKmsPostRequestProviderInputsCredential(
                type = 'access-key',
                data = infisicalapi_client.models._api_v1_external_kms_post_request_provider_inputs_credential_any_of_1_data._api_v1_external_kms_post_request_provider_inputs_credential_anyOf_1_data(
                    assume_role_arn = '0', 
                    external_id = '0', )
            )
        else:
            return ApiV1ExternalKmsPostRequestProviderInputsCredential(
                type = 'access-key',
                data = infisicalapi_client.models._api_v1_external_kms_post_request_provider_inputs_credential_any_of_1_data._api_v1_external_kms_post_request_provider_inputs_credential_anyOf_1_data(
                    assume_role_arn = '0', 
                    external_id = '0', ),
        )
        """

    def testApiV1ExternalKmsPostRequestProviderInputsCredential(self):
        """Test ApiV1ExternalKmsPostRequestProviderInputsCredential"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, conlist, validator
from infisicalapi_client.models.api_v2_service_token_post_request_scopes_inner import ApiV2ServiceTokenPostRequestScopesInner

class ApiV2ServiceTokenPostRequest(BaseModel):
    """
    ApiV2ServiceTokenPostRequest
    """
    name: StrictStr = Field(...)
    workspace_id: StrictStr = Field(default=..., alias="workspaceId")
    scopes: conlist(ApiV2ServiceTokenPostRequestScopesInner, min_items=1) = Field(...)
    encrypted_key: StrictStr = Field(default=..., alias="encryptedKey")
    iv: StrictStr = Field(...)
    tag: StrictStr = Field(...)
    expires_in: Optional[Union[StrictFloat, StrictInt]] = Field(default=..., alias="expiresIn")
    permissions: conlist(StrictStr) = Field(...)
    __properties = ["name", "workspaceId", "scopes", "encryptedKey", "iv", "tag", "expiresIn", "permissions"]

    @validator('permissions')
    def permissions_validate_enum(cls, value):
        """Validates the enum"""
        for i in value:
            if i not in ('read', 'write'):
                raise ValueError("each list item must be one of ('read', 'write')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV2ServiceTokenPostRequest:
        """Create an instance of ApiV2ServiceTokenPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in scopes (list)
        _items = []
        if self.scopes:
            for _item in self.scopes:
                if _item:
                    _items.append(_item.to_dict())
            _dict['scopes'] = _items
        # set to None if expires_in (nullable) is None
        # and __fields_set__ contains the field
        if self.expires_in is None and "expires_in" in self.__fields_set__:
            _dict['expiresIn'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV2ServiceTokenPostRequest:
        """Create an instance of ApiV2ServiceTokenPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV2ServiceTokenPostRequest.parse_obj(obj)

        _obj = ApiV2ServiceTokenPostRequest.parse_obj({
            "name": obj.get("name"),
            "workspace_id": obj.get("workspaceId"),
            "scopes": [ApiV2ServiceTokenPostRequestScopesInner.from_dict(_item) for _item in obj.get("scopes")] if obj.get("scopes") is not None else None,
            "encrypted_key": obj.get("encryptedKey"),
            "iv": obj.get("iv"),
            "tag": obj.get("tag"),
            "expires_in": obj.get("expiresIn"),
            "permissions": obj.get("permissions")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, conlist
from infisicalapi_client.models.api_v1_secret_imports_get200_response_secret_imports_inner_import_env import ApiV1SecretImportsGet200ResponseSecretImportsInnerImportEnv

class ApiV1WorkspaceGet200ResponseWorkspacesInner(BaseModel):
    """
    ApiV1WorkspaceGet200ResponseWorkspacesInner
    """
    id: StrictStr = Field(...)
    name: StrictStr = Field(...)
    slug: StrictStr = Field(...)
    auto_capitalization: Optional[StrictBool] = Field(default=True, alias="autoCapitalization")
    org_id: StrictStr = Field(default=..., alias="orgId")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    version: Optional[Union[StrictFloat, StrictInt]] = 1
    upgrade_status: Optional[StrictStr] = Field(default=None, alias="upgradeStatus")
    pit_version_limit: Optional[Union[StrictFloat, StrictInt]] = Field(default=10, alias="pitVersionLimit")
    kms_certificate_key_id: Optional[StrictStr] = Field(default=None, alias="kmsCertificateKeyId")
    audit_logs_retention_days: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="auditLogsRetentionDays")
    id: StrictStr = Field(default=..., alias="_id")
    environments: conlist(ApiV1SecretImportsGet200ResponseSecretImportsInnerImportEnv) = Field(...)
    __properties = ["id", "name", "slug", "autoCapitalization", "orgId", "createdAt", "updatedAt", "version", "upgradeStatus", "pitVersionLimit", "kmsCertificateKeyId", "auditLogsRetentionDays", "_id", "environments"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1WorkspaceGet200ResponseWorkspacesInner:
        """Create an instance of ApiV1WorkspaceGet200ResponseWorkspacesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in environments (list)
        _items = []
        if self.environments:
            for _item in self.environments:
                if _item:
                    _items.append(_item.to_dict())
            _dict['environments'] = _items
        # set to None if auto_capitalization (nullable) is None
        # and __fields_set__ contains the field
        if self.auto_capitalization is None and "auto_capitalization" in self.__fields_set__:
            _dict['autoCapitalization'] = None

        # set to None if upgrade_status (nullable) is None
        # and __fields_set__ contains the field
        if self.upgrade_status is None and "upgrade_status" in self.__fields_set__:
            _dict['upgradeStatus'] = None

        # set to None if kms_certificate_key_id (nullable) is None
        # and __fields_set__ contains the field
        if self.kms_certificate_key_id is None and "kms_certificate_key_id" in self.__fields_set__:
            _dict['kmsCertificateKeyId'] = None

        # set to None if audit_logs_retention_days (nullable) is None
        # and __fields_set__ contains the field
        if self.audit_logs_retention_days is None and "audit_logs_retention_days" in self.__fields_set__:
            _dict['auditLogsRetentionDays'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1WorkspaceGet200ResponseWorkspacesInner:
        """Create an instance of ApiV1WorkspaceGet200ResponseWorkspacesInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1WorkspaceGet200ResponseWorkspacesInner.parse_obj(obj)

        _obj = ApiV1WorkspaceGet200ResponseWorkspacesInner.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "slug": obj.get("slug"),
            "auto_capitalization": obj.get("autoCapitalization") if obj.get("autoCapitalization") is not None else True,
            "org_id": obj.get("orgId"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "version": obj.get("version") if obj.get("version") is not None else 1,
            "upgrade_status": obj.get("upgradeStatus"),
            "pit_version_limit": obj.get("pitVersionLimit") if obj.get("pitVersionLimit") is not None else 10,
            "kms_certificate_key_id": obj.get("kmsCertificateKeyId"),
            "audit_logs_retention_days": obj.get("auditLogsRetentionDays"),
            "id": obj.get("_id"),
            "environments": [ApiV1SecretImportsGet200ResponseSecretImportsInnerImportEnv.from_dict(_item) for _item in obj.get("environments")] if obj.get("environments") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist

class ApiV3SecretsMovePostRequest(BaseModel):
    """
    ApiV3SecretsMovePostRequest
    """
    project_slug: StrictStr = Field(default=..., alias="projectSlug")
    source_environment: StrictStr = Field(default=..., alias="sourceEnvironment")
    source_secret_path: Optional[StrictStr] = Field(default='/', alias="sourceSecretPath")
    destination_environment: StrictStr = Field(default=..., alias="destinationEnvironment")
    destination_secret_path: Optional[StrictStr] = Field(default='/', alias="destinationSecretPath")
    secret_ids: conlist(StrictStr) = Field(default=..., alias="secretIds")
    should_overwrite: Optional[StrictBool] = Field(default=False, alias="shouldOverwrite")
    __properties = ["projectSlug", "sourceEnvironment", "sourceSecretPath", "destinationEnvironment", "destinationSecretPath", "secretIds", "shouldOverwrite"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV3SecretsMovePostRequest:
        """Create an instance of ApiV3SecretsMovePostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV3SecretsMovePostRequest:
        """Create an instance of ApiV3SecretsMovePostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV3SecretsMovePostRequest.parse_obj(obj)

        _obj = ApiV3SecretsMovePostRequest.parse_obj({
            "project_slug": obj.get("projectSlug"),
            "source_environment": obj.get("sourceEnvironment"),
            "source_secret_path": obj.get("sourceSecretPath") if obj.get("sourceSecretPath") is not None else '/',
            "destination_environment": obj.get("destinationEnvironment"),
            "destination_secret_path": obj.get("destinationSecretPath") if obj.get("destinationSecretPath") is not None else '/',
            "secret_ids": obj.get("secretIds"),
            "should_overwrite": obj.get("shouldOverwrite") if obj.get("shouldOverwrite") is not None else False
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_identities_identity_id_identity_memberships_get200_response_identity_memberships_inner import ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner  # noqa: E501

class TestApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner(unittest.TestCase):
    """ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner:
        """Test ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner`
        """
        model = ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner()  # noqa: E501
        if include_optional:
            return ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner(
                id = '',
                identity_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                roles = [
                    infisicalapi_client.models._api_v1_workspace__workspace_id__users_get_200_response_users_inner_roles_inner._api_v1_workspace__workspaceId__users_get_200_response_users_inner_roles_inner(
                        id = '', 
                        role = '', 
                        custom_role_id = '', 
                        custom_role_name = '', 
                        custom_role_slug = '', 
                        is_temporary = True, 
                        temporary_mode = '', 
                        temporary_range = '', 
                        temporary_access_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        temporary_access_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                identity = infisicalapi_client.models._api_v1_identities_get_200_response_identities_inner_identity._api_v1_identities_get_200_response_identities_inner_identity(
                    name = '', 
                    id = '', 
                    auth_method = '', ),
                project = infisicalapi_client.models._api_v1_workspace__workspace_id__users_get_200_response_users_inner_project._api_v1_workspace__workspaceId__users_get_200_response_users_inner_project(
                    name = '', 
                    id = '', )
            )
        else:
            return ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner(
                id = '',
                identity_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                roles = [
                    infisicalapi_client.models._api_v1_workspace__workspace_id__users_get_200_response_users_inner_roles_inner._api_v1_workspace__workspaceId__users_get_200_response_users_inner_roles_inner(
                        id = '', 
                        role = '', 
                        custom_role_id = '', 
                        custom_role_name = '', 
                        custom_role_slug = '', 
                        is_temporary = True, 
                        temporary_mode = '', 
                        temporary_range = '', 
                        temporary_access_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        temporary_access_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                identity = infisicalapi_client.models._api_v1_identities_get_200_response_identities_inner_identity._api_v1_identities_get_200_response_identities_inner_identity(
                    name = '', 
                    id = '', 
                    auth_method = '', ),
                project = infisicalapi_client.models._api_v1_workspace__workspace_id__users_get_200_response_users_inner_project._api_v1_workspace__workspaceId__users_get_200_response_users_inner_project(
                    name = '', 
                    id = '', ),
        )
        """

    def testApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner(self):
        """Test ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_additional_privilege_identity_permanent_post200_response_privilege import ApiV1AdditionalPrivilegeIdentityPermanentPost200ResponsePrivilege  # noqa: E501

class TestApiV1AdditionalPrivilegeIdentityPermanentPost200ResponsePrivilege(unittest.TestCase):
    """ApiV1AdditionalPrivilegeIdentityPermanentPost200ResponsePrivilege unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1AdditionalPrivilegeIdentityPermanentPost200ResponsePrivilege:
        """Test ApiV1AdditionalPrivilegeIdentityPermanentPost200ResponsePrivilege
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1AdditionalPrivilegeIdentityPermanentPost200ResponsePrivilege`
        """
        model = ApiV1AdditionalPrivilegeIdentityPermanentPost200ResponsePrivilege()  # noqa: E501
        if include_optional:
            return ApiV1AdditionalPrivilegeIdentityPermanentPost200ResponsePrivilege(
                id = '',
                slug = '',
                project_membership_id = '',
                is_temporary = True,
                temporary_mode = '',
                temporary_range = '',
                temporary_access_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                temporary_access_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                permissions = [
                    infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_200_response_role_permissions_inner._api_v1_workspace__projectSlug__roles_post_200_response_role_permissions_inner(
                        subject = null, 
                        action = null, 
                        conditions = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_200_response_role_permissions_inner_conditions._api_v1_workspace__projectSlug__roles_post_200_response_role_permissions_inner_conditions(
                            environment = '', 
                            secret_path = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_200_response_role_permissions_inner_conditions_secret_path._api_v1_workspace__projectSlug__roles_post_200_response_role_permissions_inner_conditions_secretPath(
                                __glob = '0', ), ), )
                    ],
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return ApiV1AdditionalPrivilegeIdentityPermanentPost200ResponsePrivilege(
                id = '',
                slug = '',
                project_membership_id = '',
                permissions = [
                    infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_200_response_role_permissions_inner._api_v1_workspace__projectSlug__roles_post_200_response_role_permissions_inner(
                        subject = null, 
                        action = null, 
                        conditions = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_200_response_role_permissions_inner_conditions._api_v1_workspace__projectSlug__roles_post_200_response_role_permissions_inner_conditions(
                            environment = '', 
                            secret_path = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_200_response_role_permissions_inner_conditions_secret_path._api_v1_workspace__projectSlug__roles_post_200_response_role_permissions_inner_conditions_secretPath(
                                __glob = '0', ), ), )
                    ],
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testApiV1AdditionalPrivilegeIdentityPermanentPost200ResponsePrivilege(self):
        """Test ApiV1AdditionalPrivilegeIdentityPermanentPost200ResponsePrivilege"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class ApiV1LdapConfigPost200Response(BaseModel):
    """
    ApiV1LdapConfigPost200Response
    """
    id: StrictStr = Field(...)
    org_id: StrictStr = Field(default=..., alias="orgId")
    is_active: StrictBool = Field(default=..., alias="isActive")
    url: StrictStr = Field(...)
    encrypted_bind_dn: StrictStr = Field(default=..., alias="encryptedBindDN")
    bind_dniv: StrictStr = Field(default=..., alias="bindDNIV")
    bind_dn_tag: StrictStr = Field(default=..., alias="bindDNTag")
    encrypted_bind_pass: StrictStr = Field(default=..., alias="encryptedBindPass")
    bind_pass_iv: StrictStr = Field(default=..., alias="bindPassIV")
    bind_pass_tag: StrictStr = Field(default=..., alias="bindPassTag")
    search_base: StrictStr = Field(default=..., alias="searchBase")
    encrypted_ca_cert: StrictStr = Field(default=..., alias="encryptedCACert")
    ca_cert_iv: StrictStr = Field(default=..., alias="caCertIV")
    ca_cert_tag: StrictStr = Field(default=..., alias="caCertTag")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    group_search_base: Optional[StrictStr] = Field(default='', alias="groupSearchBase")
    group_search_filter: Optional[StrictStr] = Field(default='', alias="groupSearchFilter")
    search_filter: Optional[StrictStr] = Field(default='', alias="searchFilter")
    unique_user_attribute: Optional[StrictStr] = Field(default='', alias="uniqueUserAttribute")
    __properties = ["id", "orgId", "isActive", "url", "encryptedBindDN", "bindDNIV", "bindDNTag", "encryptedBindPass", "bindPassIV", "bindPassTag", "searchBase", "encryptedCACert", "caCertIV", "caCertTag", "createdAt", "updatedAt", "groupSearchBase", "groupSearchFilter", "searchFilter", "uniqueUserAttribute"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1LdapConfigPost200Response:
        """Create an instance of ApiV1LdapConfigPost200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1LdapConfigPost200Response:
        """Create an instance of ApiV1LdapConfigPost200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1LdapConfigPost200Response.parse_obj(obj)

        _obj = ApiV1LdapConfigPost200Response.parse_obj({
            "id": obj.get("id"),
            "org_id": obj.get("orgId"),
            "is_active": obj.get("isActive"),
            "url": obj.get("url"),
            "encrypted_bind_dn": obj.get("encryptedBindDN"),
            "bind_dniv": obj.get("bindDNIV"),
            "bind_dn_tag": obj.get("bindDNTag"),
            "encrypted_bind_pass": obj.get("encryptedBindPass"),
            "bind_pass_iv": obj.get("bindPassIV"),
            "bind_pass_tag": obj.get("bindPassTag"),
            "search_base": obj.get("searchBase"),
            "encrypted_ca_cert": obj.get("encryptedCACert"),
            "ca_cert_iv": obj.get("caCertIV"),
            "ca_cert_tag": obj.get("caCertTag"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "group_search_base": obj.get("groupSearchBase") if obj.get("groupSearchBase") is not None else '',
            "group_search_filter": obj.get("groupSearchFilter") if obj.get("groupSearchFilter") is not None else '',
            "search_filter": obj.get("searchFilter") if obj.get("searchFilter") is not None else '',
            "unique_user_attribute": obj.get("uniqueUserAttribute") if obj.get("uniqueUserAttribute") is not None else ''
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner(BaseModel):
    """
    ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner
    """
    op: StrictStr = Field(...)
    secret_id: Optional[StrictStr] = Field(default=None, alias="secretId")
    __properties = ["op", "secretId"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner:
        """Create an instance of ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if secret_id (nullable) is None
        # and __fields_set__ contains the field
        if self.secret_id is None and "secret_id" in self.__fields_set__:
            _dict['secretId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner:
        """Create an instance of ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner.parse_obj(obj)

        _obj = ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner.parse_obj({
            "op": obj.get("op"),
            "secret_id": obj.get("secretId")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr
from infisicalapi_client.models.api_v1_secret_approvals_get200_response_approvals_inner_environment import ApiV1SecretApprovalsGet200ResponseApprovalsInnerEnvironment

class ApiV1WebhooksPost200ResponseWebhook(BaseModel):
    """
    ApiV1WebhooksPost200ResponseWebhook
    """
    id: StrictStr = Field(...)
    secret_path: Optional[StrictStr] = Field(default='/', alias="secretPath")
    last_status: Optional[StrictStr] = Field(default=None, alias="lastStatus")
    last_run_error_message: Optional[StrictStr] = Field(default=None, alias="lastRunErrorMessage")
    is_disabled: Optional[StrictBool] = Field(default=False, alias="isDisabled")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    env_id: StrictStr = Field(default=..., alias="envId")
    type: Optional[StrictStr] = 'general'
    project_id: StrictStr = Field(default=..., alias="projectId")
    environment: ApiV1SecretApprovalsGet200ResponseApprovalsInnerEnvironment = Field(...)
    __properties = ["id", "secretPath", "lastStatus", "lastRunErrorMessage", "isDisabled", "createdAt", "updatedAt", "envId", "type", "projectId", "environment"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1WebhooksPost200ResponseWebhook:
        """Create an instance of ApiV1WebhooksPost200ResponseWebhook from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of environment
        if self.environment:
            _dict['environment'] = self.environment.to_dict()
        # set to None if last_status (nullable) is None
        # and __fields_set__ contains the field
        if self.last_status is None and "last_status" in self.__fields_set__:
            _dict['lastStatus'] = None

        # set to None if last_run_error_message (nullable) is None
        # and __fields_set__ contains the field
        if self.last_run_error_message is None and "last_run_error_message" in self.__fields_set__:
            _dict['lastRunErrorMessage'] = None

        # set to None if type (nullable) is None
        # and __fields_set__ contains the field
        if self.type is None and "type" in self.__fields_set__:
            _dict['type'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1WebhooksPost200ResponseWebhook:
        """Create an instance of ApiV1WebhooksPost200ResponseWebhook from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1WebhooksPost200ResponseWebhook.parse_obj(obj)

        _obj = ApiV1WebhooksPost200ResponseWebhook.parse_obj({
            "id": obj.get("id"),
            "secret_path": obj.get("secretPath") if obj.get("secretPath") is not None else '/',
            "last_status": obj.get("lastStatus"),
            "last_run_error_message": obj.get("lastRunErrorMessage"),
            "is_disabled": obj.get("isDisabled") if obj.get("isDisabled") is not None else False,
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "env_id": obj.get("envId"),
            "type": obj.get("type") if obj.get("type") is not None else 'general',
            "project_id": obj.get("projectId"),
            "environment": ApiV1SecretApprovalsGet200ResponseApprovalsInnerEnvironment.from_dict(obj.get("environment")) if obj.get("environment") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_access_approvals_requests_get200_response_requests_inner import ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner  # noqa: E501

class TestApiV1AccessApprovalsRequestsGet200ResponseRequestsInner(unittest.TestCase):
    """ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner:
        """Test ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner`
        """
        model = ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner()  # noqa: E501
        if include_optional:
            return ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner(
                id = '',
                policy_id = '',
                privilege_id = '',
                requested_by = '',
                is_temporary = True,
                temporary_range = '',
                permissions = None,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                environment_name = '',
                is_approved = True,
                privilege = infisicalapi_client.models._api_v1_access_approvals_requests_get_200_response_requests_inner_privilege._api_v1_access_approvals_requests_get_200_response_requests_inner_privilege(
                    membership_id = '', 
                    is_temporary = True, 
                    temporary_mode = '', 
                    temporary_range = '', 
                    temporary_access_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    temporary_access_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    permissions = null, ),
                policy = infisicalapi_client.models._api_v1_access_approvals_requests_get_200_response_requests_inner_policy._api_v1_access_approvals_requests_get_200_response_requests_inner_policy(
                    id = '', 
                    name = '', 
                    approvals = 1.337, 
                    approvers = [
                        ''
                        ], 
                    secret_path = '', 
                    env_id = '', 
                    enforcement_level = '', ),
                reviewers = [
                    infisicalapi_client.models._api_v1_access_approvals_requests_get_200_response_requests_inner_reviewers_inner._api_v1_access_approvals_requests_get_200_response_requests_inner_reviewers_inner(
                        member = '', 
                        status = '', )
                    ]
            )
        else:
            return ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner(
                id = '',
                policy_id = '',
                requested_by = '',
                is_temporary = True,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                environment_name = '',
                is_approved = True,
                privilege = infisicalapi_client.models._api_v1_access_approvals_requests_get_200_response_requests_inner_privilege._api_v1_access_approvals_requests_get_200_response_requests_inner_privilege(
                    membership_id = '', 
                    is_temporary = True, 
                    temporary_mode = '', 
                    temporary_range = '', 
                    temporary_access_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    temporary_access_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    permissions = null, ),
                policy = infisicalapi_client.models._api_v1_access_approvals_requests_get_200_response_requests_inner_policy._api_v1_access_approvals_requests_get_200_response_requests_inner_policy(
                    id = '', 
                    name = '', 
                    approvals = 1.337, 
                    approvers = [
                        ''
                        ], 
                    secret_path = '', 
                    env_id = '', 
                    enforcement_level = '', ),
                reviewers = [
                    infisicalapi_client.models._api_v1_access_approvals_requests_get_200_response_requests_inner_reviewers_inner._api_v1_access_approvals_requests_get_200_response_requests_inner_reviewers_inner(
                        member = '', 
                        status = '', )
                    ],
        )
        """

    def testApiV1AccessApprovalsRequestsGet200ResponseRequestsInner(self):
        """Test ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner(BaseModel):
    """
    ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner
    """
    id: StrictStr = Field(...)
    role: StrictStr = Field(...)
    custom_role_id: Optional[StrictStr] = Field(default=None, alias="customRoleId")
    custom_role_name: Optional[StrictStr] = Field(default=None, alias="customRoleName")
    custom_role_slug: Optional[StrictStr] = Field(default=None, alias="customRoleSlug")
    is_temporary: StrictBool = Field(default=..., alias="isTemporary")
    temporary_mode: Optional[StrictStr] = Field(default=None, alias="temporaryMode")
    temporary_range: Optional[StrictStr] = Field(default=None, alias="temporaryRange")
    temporary_access_start_time: Optional[datetime] = Field(default=None, alias="temporaryAccessStartTime")
    temporary_access_end_time: Optional[datetime] = Field(default=None, alias="temporaryAccessEndTime")
    __properties = ["id", "role", "customRoleId", "customRoleName", "customRoleSlug", "isTemporary", "temporaryMode", "temporaryRange", "temporaryAccessStartTime", "temporaryAccessEndTime"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner:
        """Create an instance of ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if custom_role_id (nullable) is None
        # and __fields_set__ contains the field
        if self.custom_role_id is None and "custom_role_id" in self.__fields_set__:
            _dict['customRoleId'] = None

        # set to None if custom_role_name (nullable) is None
        # and __fields_set__ contains the field
        if self.custom_role_name is None and "custom_role_name" in self.__fields_set__:
            _dict['customRoleName'] = None

        # set to None if custom_role_slug (nullable) is None
        # and __fields_set__ contains the field
        if self.custom_role_slug is None and "custom_role_slug" in self.__fields_set__:
            _dict['customRoleSlug'] = None

        # set to None if temporary_mode (nullable) is None
        # and __fields_set__ contains the field
        if self.temporary_mode is None and "temporary_mode" in self.__fields_set__:
            _dict['temporaryMode'] = None

        # set to None if temporary_range (nullable) is None
        # and __fields_set__ contains the field
        if self.temporary_range is None and "temporary_range" in self.__fields_set__:
            _dict['temporaryRange'] = None

        # set to None if temporary_access_start_time (nullable) is None
        # and __fields_set__ contains the field
        if self.temporary_access_start_time is None and "temporary_access_start_time" in self.__fields_set__:
            _dict['temporaryAccessStartTime'] = None

        # set to None if temporary_access_end_time (nullable) is None
        # and __fields_set__ contains the field
        if self.temporary_access_end_time is None and "temporary_access_end_time" in self.__fields_set__:
            _dict['temporaryAccessEndTime'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner:
        """Create an instance of ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner.parse_obj(obj)

        _obj = ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner.parse_obj({
            "id": obj.get("id"),
            "role": obj.get("role"),
            "custom_role_id": obj.get("customRoleId"),
            "custom_role_name": obj.get("customRoleName"),
            "custom_role_slug": obj.get("customRoleSlug"),
            "is_temporary": obj.get("isTemporary"),
            "temporary_mode": obj.get("temporaryMode"),
            "temporary_range": obj.get("temporaryRange"),
            "temporary_access_start_time": obj.get("temporaryAccessStartTime"),
            "temporary_access_end_time": obj.get("temporaryAccessEndTime")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, conlist
from infisicalapi_client.models.api_v1_scim_users_get200_response_resources_inner import ApiV1ScimUsersGet200ResponseResourcesInner

class ApiV1ScimUsersGet200Response(BaseModel):
    """
    ApiV1ScimUsersGet200Response
    """
    resources: conlist(ApiV1ScimUsersGet200ResponseResourcesInner) = Field(default=..., alias="Resources")
    items_per_page: Union[StrictFloat, StrictInt] = Field(default=..., alias="itemsPerPage")
    schemas: conlist(StrictStr) = Field(...)
    start_index: Union[StrictFloat, StrictInt] = Field(default=..., alias="startIndex")
    total_results: Union[StrictFloat, StrictInt] = Field(default=..., alias="totalResults")
    __properties = ["Resources", "itemsPerPage", "schemas", "startIndex", "totalResults"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1ScimUsersGet200Response:
        """Create an instance of ApiV1ScimUsersGet200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in resources (list)
        _items = []
        if self.resources:
            for _item in self.resources:
                if _item:
                    _items.append(_item.to_dict())
            _dict['Resources'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1ScimUsersGet200Response:
        """Create an instance of ApiV1ScimUsersGet200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1ScimUsersGet200Response.parse_obj(obj)

        _obj = ApiV1ScimUsersGet200Response.parse_obj({
            "resources": [ApiV1ScimUsersGet200ResponseResourcesInner.from_dict(_item) for _item in obj.get("Resources")] if obj.get("Resources") is not None else None,
            "items_per_page": obj.get("itemsPerPage"),
            "schemas": obj.get("schemas"),
            "start_index": obj.get("startIndex"),
            "total_results": obj.get("totalResults")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, validator

class ApiV3SecretsSecretNamePostRequest(BaseModel):
    """
    ApiV3SecretsSecretNamePostRequest
    """
    workspace_id: StrictStr = Field(default=..., alias="workspaceId")
    environment: StrictStr = Field(...)
    type: Optional[StrictStr] = 'shared'
    secret_path: Optional[StrictStr] = Field(default='/', alias="secretPath")
    secret_key_ciphertext: StrictStr = Field(default=..., alias="secretKeyCiphertext")
    secret_key_iv: StrictStr = Field(default=..., alias="secretKeyIV")
    secret_key_tag: StrictStr = Field(default=..., alias="secretKeyTag")
    secret_value_ciphertext: StrictStr = Field(default=..., alias="secretValueCiphertext")
    secret_value_iv: StrictStr = Field(default=..., alias="secretValueIV")
    secret_value_tag: StrictStr = Field(default=..., alias="secretValueTag")
    secret_comment_ciphertext: Optional[StrictStr] = Field(default=None, alias="secretCommentCiphertext")
    secret_comment_iv: Optional[StrictStr] = Field(default=None, alias="secretCommentIV")
    secret_comment_tag: Optional[StrictStr] = Field(default=None, alias="secretCommentTag")
    metadata: Optional[Dict[str, StrictStr]] = None
    skip_multiline_encoding: Optional[StrictBool] = Field(default=None, alias="skipMultilineEncoding")
    __properties = ["workspaceId", "environment", "type", "secretPath", "secretKeyCiphertext", "secretKeyIV", "secretKeyTag", "secretValueCiphertext", "secretValueIV", "secretValueTag", "secretCommentCiphertext", "secretCommentIV", "secretCommentTag", "metadata", "skipMultilineEncoding"]

    @validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('shared', 'personal'):
            raise ValueError("must be one of enum values ('shared', 'personal')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV3SecretsSecretNamePostRequest:
        """Create an instance of ApiV3SecretsSecretNamePostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV3SecretsSecretNamePostRequest:
        """Create an instance of ApiV3SecretsSecretNamePostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV3SecretsSecretNamePostRequest.parse_obj(obj)

        _obj = ApiV3SecretsSecretNamePostRequest.parse_obj({
            "workspace_id": obj.get("workspaceId"),
            "environment": obj.get("environment"),
            "type": obj.get("type") if obj.get("type") is not None else 'shared',
            "secret_path": obj.get("secretPath") if obj.get("secretPath") is not None else '/',
            "secret_key_ciphertext": obj.get("secretKeyCiphertext"),
            "secret_key_iv": obj.get("secretKeyIV"),
            "secret_key_tag": obj.get("secretKeyTag"),
            "secret_value_ciphertext": obj.get("secretValueCiphertext"),
            "secret_value_iv": obj.get("secretValueIV"),
            "secret_value_tag": obj.get("secretValueTag"),
            "secret_comment_ciphertext": obj.get("secretCommentCiphertext"),
            "secret_comment_iv": obj.get("secretCommentIV"),
            "secret_comment_tag": obj.get("secretCommentTag"),
            "metadata": obj.get("metadata"),
            "skip_multiline_encoding": obj.get("skipMultilineEncoding")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_admin_config_patch_request import ApiV1AdminConfigPatchRequest  # noqa: E501

class TestApiV1AdminConfigPatchRequest(unittest.TestCase):
    """ApiV1AdminConfigPatchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1AdminConfigPatchRequest:
        """Test ApiV1AdminConfigPatchRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1AdminConfigPatchRequest`
        """
        model = ApiV1AdminConfigPatchRequest()  # noqa: E501
        if include_optional:
            return ApiV1AdminConfigPatchRequest(
                allow_sign_up = True,
                allowed_sign_up_domain = '',
                trust_saml_emails = True,
                trust_ldap_emails = True,
                trust_oidc_emails = True,
                default_auth_org_id = '',
                enabled_login_methods = [
                    'email'
                    ]
            )
        else:
            return ApiV1AdminConfigPatchRequest(
        )
        """

    def testApiV1AdminConfigPatchRequest(self):
        """Test ApiV1AdminConfigPatchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_pki_ca_post_request import ApiV1PkiCaPostRequest  # noqa: E501

class TestApiV1PkiCaPostRequest(unittest.TestCase):
    """ApiV1PkiCaPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1PkiCaPostRequest:
        """Test ApiV1PkiCaPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1PkiCaPostRequest`
        """
        model = ApiV1PkiCaPostRequest()  # noqa: E501
        if include_optional:
            return ApiV1PkiCaPostRequest(
                project_slug = '',
                type = 'root',
                friendly_name = '',
                common_name = '',
                organization = '',
                ou = '',
                country = '',
                province = '',
                locality = '',
                not_before = '',
                not_after = '',
                max_path_length = -1,
                key_algorithm = 'RSA_2048'
            )
        else:
            return ApiV1PkiCaPostRequest(
                project_slug = '',
                type = 'root',
                common_name = '',
                organization = '',
                ou = '',
                country = '',
                province = '',
                locality = '',
        )
        """

    def testApiV1PkiCaPostRequest(self):
        """Test ApiV1PkiCaPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_approval_requests_id_get200_response_approval import ApiV1SecretApprovalRequestsIdGet200ResponseApproval  # noqa: E501

class TestApiV1SecretApprovalRequestsIdGet200ResponseApproval(unittest.TestCase):
    """ApiV1SecretApprovalRequestsIdGet200ResponseApproval unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretApprovalRequestsIdGet200ResponseApproval:
        """Test ApiV1SecretApprovalRequestsIdGet200ResponseApproval
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretApprovalRequestsIdGet200ResponseApproval`
        """
        model = ApiV1SecretApprovalRequestsIdGet200ResponseApproval()  # noqa: E501
        if include_optional:
            return ApiV1SecretApprovalRequestsIdGet200ResponseApproval(
                id = '',
                policy_id = '',
                has_merged = True,
                status = 'open',
                conflicts = None,
                slug = '',
                folder_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                is_replicated = True,
                committer_user_id = '',
                status_changed_by_user_id = '',
                bypass_reason = '',
                policy = infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_policy._api_v1_secret_approval_requests__id__get_200_response_approval_policy(
                    id = '', 
                    name = '', 
                    approvals = 1.337, 
                    approvers = [
                        infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_committer_user._api_v1_secret_approval_requests_get_200_response_approvals_inner_committerUser(
                            user_id = '', 
                            email = '', 
                            first_name = '', 
                            last_name = '', 
                            username = '', )
                        ], 
                    secret_path = '', 
                    enforcement_level = '', ),
                environment = '',
                status_changed_by_user = infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_committer_user._api_v1_secret_approval_requests_get_200_response_approvals_inner_committerUser(
                    user_id = '', 
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    username = '', ),
                committer_user = infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_committer_user._api_v1_secret_approval_requests_get_200_response_approvals_inner_committerUser(
                    user_id = '', 
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    username = '', ),
                reviewers = [
                    infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_reviewers_inner._api_v1_secret_approval_requests__id__get_200_response_approval_reviewers_inner(
                        user_id = '', 
                        email = '', 
                        first_name = '', 
                        last_name = '', 
                        username = '', 
                        status = '', )
                    ],
                secret_path = '',
                commits = [
                    infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner(
                        id = '', 
                        secret_key = '', 
                        secret_value = '', 
                        secret_comment = '', 
                        secret_reminder_note = '', 
                        secret_reminder_repeat_days = 1.337, 
                        skip_multiline_encoding = True, 
                        metadata = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        op = '', 
                        tags = [
                            infisicalapi_client.models._api_v1_secret_snapshot__secret_snapshot_id__get_200_response_secret_snapshot_secret_versions_inner_tags_inner._api_v1_secret_snapshot__secretSnapshotId__get_200_response_secretSnapshot_secretVersions_inner_tags_inner(
                                id = '', 
                                slug = '', 
                                color = '', )
                            ], 
                        secret = infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secret._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secret(
                            id = '', 
                            version = 1.337, 
                            secret_key = '', 
                            secret_value = '', 
                            secret_comment = '', ), 
                        secret_version = infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secret_version._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secretVersion(
                            id = '', 
                            version = 1.337, 
                            secret_key = '', 
                            secret_value = '', 
                            secret_comment = '', ), )
                    ]
            )
        else:
            return ApiV1SecretApprovalRequestsIdGet200ResponseApproval(
                id = '',
                policy_id = '',
                slug = '',
                folder_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                committer_user_id = '',
                policy = infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_policy._api_v1_secret_approval_requests__id__get_200_response_approval_policy(
                    id = '', 
                    name = '', 
                    approvals = 1.337, 
                    approvers = [
                        infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_committer_user._api_v1_secret_approval_requests_get_200_response_approvals_inner_committerUser(
                            user_id = '', 
                            email = '', 
                            first_name = '', 
                            last_name = '', 
                            username = '', )
                        ], 
                    secret_path = '', 
                    enforcement_level = '', ),
                environment = '',
                committer_user = infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_committer_user._api_v1_secret_approval_requests_get_200_response_approvals_inner_committerUser(
                    user_id = '', 
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    username = '', ),
                reviewers = [
                    infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_reviewers_inner._api_v1_secret_approval_requests__id__get_200_response_approval_reviewers_inner(
                        user_id = '', 
                        email = '', 
                        first_name = '', 
                        last_name = '', 
                        username = '', 
                        status = '', )
                    ],
                secret_path = '',
                commits = [
                    infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner(
                        id = '', 
                        secret_key = '', 
                        secret_value = '', 
                        secret_comment = '', 
                        secret_reminder_note = '', 
                        secret_reminder_repeat_days = 1.337, 
                        skip_multiline_encoding = True, 
                        metadata = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        op = '', 
                        tags = [
                            infisicalapi_client.models._api_v1_secret_snapshot__secret_snapshot_id__get_200_response_secret_snapshot_secret_versions_inner_tags_inner._api_v1_secret_snapshot__secretSnapshotId__get_200_response_secretSnapshot_secretVersions_inner_tags_inner(
                                id = '', 
                                slug = '', 
                                color = '', )
                            ], 
                        secret = infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secret._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secret(
                            id = '', 
                            version = 1.337, 
                            secret_key = '', 
                            secret_value = '', 
                            secret_comment = '', ), 
                        secret_version = infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secret_version._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secretVersion(
                            id = '', 
                            version = 1.337, 
                            secret_key = '', 
                            secret_value = '', 
                            secret_comment = '', ), )
                    ],
        )
        """

    def testApiV1SecretApprovalRequestsIdGet200ResponseApproval(self):
        """Test ApiV1SecretApprovalRequestsIdGet200ResponseApproval"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



import base64
import json
from typing import List, Union
import os
import json
import base64
import datetime
from typing import Dict, Any

import requests
import boto3
from botocore.auth import SigV4Auth
from botocore.awsrequest import AWSRequest
from botocore.exceptions import NoCredentialsError


import infisicalapi_client 
from infisicalapi_client.models.api_v1_auth_aws_auth_login_post_request import ApiV1AuthAwsAuthLoginPostRequest
from infisicalapi_client.models.api_v1_auth_token_auth_identities_identity_id_tokens_post200_response import ApiV1AuthTokenAuthIdentitiesIdentityIdTokensPost200Response
from infisicalapi_client.models.api_v1_auth_universal_auth_login_post_request import ApiV1AuthUniversalAuthLoginPostRequest
from infisicalapi_client.models.api_v3_secrets_raw_get200_response import ApiV3SecretsRawGet200Response
from infisicalapi_client.models.api_v3_secrets_raw_secret_name_delete_request import ApiV3SecretsRawSecretNameDeleteRequest
from infisicalapi_client.models.api_v3_secrets_raw_secret_name_get200_response import ApiV3SecretsRawSecretNameGet200Response
from infisicalapi_client.models.api_v3_secrets_raw_secret_name_patch_request import ApiV3SecretsRawSecretNamePatchRequest
from infisicalapi_client.models.api_v3_secrets_raw_secret_name_post200_response import ApiV3SecretsRawSecretNamePost200Response
from infisicalapi_client.models.api_v3_secrets_raw_secret_name_post_request import ApiV3SecretsRawSecretNamePostRequest

class InfisicalSDKClient:
    def __init__(self, host: str, token: str  = None):
        self.host = host
        self.token_type = None
        self.expires_in = None

        self._api_config = infisicalapi_client.Configuration(host=host, access_token=token)
        self._api_client = infisicalapi_client.ApiClient(self._api_config)
        self._api_instance = infisicalapi_client.DefaultApi(self._api_client)
        self.rest = self._api_instance

        self.auth = Auth(self)
        self.secrets = V3RawSecrets(self)

    def set_token(self, token: str):
        """
        Set the access token for future requests.
        """
        self._api_config.access_token = token

    def get_token(self):
        """
        Set the access token for future requests.
        """
        return self.token


class UniversalAuth:
    def __init__(self, client: InfisicalSDKClient):
        self.client = client

    def login(self, client_id: str, client_secret: str) -> ApiV1AuthTokenAuthIdentitiesIdentityIdTokensPost200Response:
        """
        Login with Universal Auth.

        Args:
            client_id (str): Your Machine Identity Client ID.
            client_secret (str): Your Machine Identity Client Secret.

        Returns:
            Dict: A dictionary containing the access token and related information.
        """

        response = self.client._api_instance.api_v1_auth_universal_auth_login_post(ApiV1AuthUniversalAuthLoginPostRequest(
            client_id = client_id,
            client_secret = client_secret
        ))

        self.client.set_token(response.access_token)

        return response
    

class AWSAuth:
    def __init__(self, client: InfisicalSDKClient) -> None:
        self.client = client

    def login(self, identity_id: str) -> ApiV1AuthTokenAuthIdentitiesIdentityIdTokensPost200Response:
        """
        Login with AWS Authentication. 

        Args:
            identity_id (str): Your Machine Identity ID that has AWS Auth configured.

        Returns:
            Dict: A dictionary containing the access token and related information.
        """

        identity_id = identity_id or os.getenv("INFISICAL_AWS_IAM_AUTH_IDENTITY_ID")
        if not identity_id:
            raise ValueError("Identity ID must be provided or set in the environment variable INFISICAL_AWS_IAM_AUTH_IDENTITY_ID.")

        aws_region = self.get_aws_region()
        session = boto3.Session(region_name=aws_region)

        credentials = self._get_aws_credentials(session)

        iam_request_url = f"https://sts.{aws_region}.amazonaws.com/"
        iam_request_body = "Action=GetCallerIdentity&Version=2011-06-15"
        request_headers = self._prepare_aws_request(iam_request_url, iam_request_body, credentials, aws_region)

        login_request = ApiV1AuthAwsAuthLoginPostRequest(
            identityId=identity_id,
            iamRequestBody=base64.b64encode(iam_request_body.encode()).decode(),
            iamRequestHeaders=base64.b64encode(json.dumps(request_headers).encode()).decode(),
            iamHttpRequestMethod="POST"
        )

        response = self.client._api_instance.api_v1_auth_aws_auth_login_post(login_request)
        self.client.set_token(response.access_token)

        return response

    def _get_aws_credentials(self, session: boto3.Session) -> Any:
        try:
            credentials = session.get_credentials()
            if credentials is None:
                raise NoCredentialsError("AWS credentials not found.")
            return credentials.get_frozen_credentials()
        except NoCredentialsError as e:
            raise RuntimeError(f"AWS IAM Auth Login failed: {str(e)}")

    def _prepare_aws_request(self, url: str, body: str, credentials: Any, region: str) -> Dict[str, str]:
        current_time = datetime.datetime.now(datetime.timezone.utc)
        amz_date = current_time.strftime('%Y%m%dT%H%M%SZ')
        
        request = AWSRequest(method="POST", url=url, data=body)
        request.headers["X-Amz-Date"] = amz_date
        request.headers["Host"] = f"sts.{region}.amazonaws.com"
        request.headers["Content-Type"] = "application/x-www-form-urlencoded; charset=utf-8"
        request.headers["Content-Length"] = str(len(body))

        signer = SigV4Auth(credentials, "sts", region)
        signer.add_auth(request)
        
        return {k: v for k, v in request.headers.items() if k.lower() != "content-length"}

    @staticmethod
    def get_aws_region() -> str:
        region = os.getenv("AWS_REGION") # Typically found in lambda runtime environment
        if region:
            return region

        try:
            return AWSAuth._get_aws_ec2_identity_document_region()
        except Exception as e:
            raise Exception("Failed to retrieve AWS region") from e

    @staticmethod
    def _get_aws_ec2_identity_document_region(timeout: int = 5000) -> str:
        session = requests.Session()
        token_response = session.put(
            "http://169.254.169.254/latest/api/token",
            headers={"X-aws-ec2-metadata-token-ttl-seconds": "21600"},
            timeout=timeout / 1000
        )
        token_response.raise_for_status()
        metadata_token = token_response.text

        identity_response = session.get(
            "http://169.254.169.254/latest/dynamic/instance-identity/document",
            headers={"X-aws-ec2-metadata-token": metadata_token, "Accept": "application/json"},
            timeout=timeout / 1000
        )

        identity_response.raise_for_status()
        return identity_response.json().get("region")


class Auth:
    def __init__(self, client):
        self.client = client
        self.aws_auth = AWSAuth(client)
        self.universal_auth = UniversalAuth(client)

class V3RawSecrets:
    def __init__(self, client: InfisicalSDKClient) -> None:
        self.client = client

    def list_secrets(self, project_id: str, environment_slug: str, secret_path: str, expand_secret_references: bool = True, recursive: bool = False, include_imports : bool = True, tag_filters: List[str] = []) -> ApiV3SecretsRawGet200Response:
        return self.client._api_instance.api_v3_secrets_raw_get(
            workspace_id=project_id, 
            environment=environment_slug, 
            secret_path=secret_path, 
            expand_secret_references=str(expand_secret_references).lower(), 
            recursive=str(recursive).lower(), 
            tag_slugs=",".join(tag_filters), 
            include_imports=str(include_imports).lower())

    def create_secret_by_name(self, secret_name: str, project_id: str, secret_path: str, environment_slug: str, secret_value: str = None, secret_comment: str = None, skip_multiline_encoding: bool = False, secret_reminder_repeat_days: Union[float, int] = None, secret_reminder_note: str = None) -> ApiV3SecretsRawSecretNamePost200Response:
        secret_request = ApiV3SecretsRawSecretNamePostRequest(
            workspaceId = project_id,
            environment = environment_slug,
            secretPath= secret_path,
            secretValue = secret_value,
            secretComment = secret_comment,
            tagIds = None,
            skipMultilineEncoding = skip_multiline_encoding,
            type = "shared",
            secretReminderRepeatDays = secret_reminder_repeat_days,
            secretReminderNote = secret_reminder_note
        )

        return self.client._api_instance.api_v3_secrets_raw_secret_name_post(secret_name, secret_request)
         

    def update_secret_by_name(self, current_secret_name: str, project_id: str, secret_path: str, environment_slug: str, secret_value: str = None, secret_comment: str = None, skip_multiline_encoding: bool = False, secret_reminder_repeat_days: Union[float, int] = None, secret_reminder_note: str = None, new_secret_name: str = None) -> ApiV3SecretsRawSecretNamePost200Response:
        secret_request = ApiV3SecretsRawSecretNamePatchRequest(
            workspaceId = project_id,
            environment = environment_slug,
            secretPath= secret_path,
            secretValue = secret_value,
            secretComment = secret_comment,
            new_secret_name=new_secret_name,
            tagIds = None,
            skipMultilineEncoding = skip_multiline_encoding,
            type = "shared",
            secretReminderRepeatDays = secret_reminder_repeat_days,
            secretReminderNote = secret_reminder_note
        )

        return self.client._api_instance.api_v3_secrets_raw_secret_name_patch(current_secret_name, secret_request) 

    def delete_secret_by_name(self, secret_name: str, project_id: str, secret_path: str, environment_slug: str) -> ApiV3SecretsRawSecretNamePost200Response:
        secret_delete_request = ApiV3SecretsRawSecretNameDeleteRequest(
            workspaceId = project_id,
            environment = environment_slug,
            secretPath= secret_path,
            type = "shared",
        )

        return self.client._api_instance.api_v3_secrets_raw_secret_name_delete(secret_name, secret_delete_request)

    def get_secret_by_name(self, secret_name: str, project_id: str, environment_slug: str, secret_path: str, expand_secret_references: bool = True, include_imports : bool = True, version: str = None) -> ApiV3SecretsRawSecretNameGet200Response:
        return self.client._api_instance.api_v3_secrets_raw_secret_name_get(
            secret_name=secret_name,
            workspace_id=project_id, 
            environment=environment_slug, 
            secret_path=secret_path,
            version=version, 
            type="shared",
            expand_secret_references=str(expand_secret_references).lower(), 
            include_imports=str(include_imports).lower()
        )



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from infisicalapi_client.models.api_v2_workspace_workspace_id_encrypted_key_get200_response_sender import ApiV2WorkspaceWorkspaceIdEncryptedKeyGet200ResponseSender

class ApiV2WorkspaceWorkspaceIdEncryptedKeyGet200Response(BaseModel):
    """
    ApiV2WorkspaceWorkspaceIdEncryptedKeyGet200Response
    """
    id: StrictStr = Field(...)
    encrypted_key: StrictStr = Field(default=..., alias="encryptedKey")
    nonce: StrictStr = Field(...)
    receiver_id: StrictStr = Field(default=..., alias="receiverId")
    sender_id: Optional[StrictStr] = Field(default=None, alias="senderId")
    project_id: StrictStr = Field(default=..., alias="projectId")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    sender: ApiV2WorkspaceWorkspaceIdEncryptedKeyGet200ResponseSender = Field(...)
    __properties = ["id", "encryptedKey", "nonce", "receiverId", "senderId", "projectId", "createdAt", "updatedAt", "sender"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV2WorkspaceWorkspaceIdEncryptedKeyGet200Response:
        """Create an instance of ApiV2WorkspaceWorkspaceIdEncryptedKeyGet200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of sender
        if self.sender:
            _dict['sender'] = self.sender.to_dict()
        # set to None if sender_id (nullable) is None
        # and __fields_set__ contains the field
        if self.sender_id is None and "sender_id" in self.__fields_set__:
            _dict['senderId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV2WorkspaceWorkspaceIdEncryptedKeyGet200Response:
        """Create an instance of ApiV2WorkspaceWorkspaceIdEncryptedKeyGet200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV2WorkspaceWorkspaceIdEncryptedKeyGet200Response.parse_obj(obj)

        _obj = ApiV2WorkspaceWorkspaceIdEncryptedKeyGet200Response.parse_obj({
            "id": obj.get("id"),
            "encrypted_key": obj.get("encryptedKey"),
            "nonce": obj.get("nonce"),
            "receiver_id": obj.get("receiverId"),
            "sender_id": obj.get("senderId"),
            "project_id": obj.get("projectId"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "sender": ApiV2WorkspaceWorkspaceIdEncryptedKeyGet200ResponseSender.from_dict(obj.get("sender")) if obj.get("sender") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_workspace_workspace_id_integrations_get200_response import ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response  # noqa: E501

class TestApiV1WorkspaceWorkspaceIdIntegrationsGet200Response(unittest.TestCase):
    """ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response:
        """Test ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response`
        """
        model = ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response()  # noqa: E501
        if include_optional:
            return ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response(
                integrations = [
                    infisicalapi_client.models._api_v1_workspace__workspace_id__integrations_get_200_response_integrations_inner._api_v1_workspace__workspaceId__integrations_get_200_response_integrations_inner(
                        id = '', 
                        is_active = True, 
                        url = '', 
                        app = '', 
                        app_id = '', 
                        target_environment = '', 
                        target_environment_id = '', 
                        target_service = '', 
                        target_service_id = '', 
                        owner = '', 
                        path = '', 
                        region = '', 
                        scope = '', 
                        integration = '', 
                        metadata = null, 
                        integration_auth_id = '', 
                        env_id = '', 
                        secret_path = '/', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_used = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        is_synced = True, 
                        sync_message = '', 
                        last_sync_job_id = '', 
                        environment = infisicalapi_client.models._api_v1_secret_approvals_get_200_response_approvals_inner_environment._api_v1_secret_approvals_get_200_response_approvals_inner_environment(
                            id = '', 
                            name = '', 
                            slug = '', ), )
                    ]
            )
        else:
            return ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response(
                integrations = [
                    infisicalapi_client.models._api_v1_workspace__workspace_id__integrations_get_200_response_integrations_inner._api_v1_workspace__workspaceId__integrations_get_200_response_integrations_inner(
                        id = '', 
                        is_active = True, 
                        url = '', 
                        app = '', 
                        app_id = '', 
                        target_environment = '', 
                        target_environment_id = '', 
                        target_service = '', 
                        target_service_id = '', 
                        owner = '', 
                        path = '', 
                        region = '', 
                        scope = '', 
                        integration = '', 
                        metadata = null, 
                        integration_auth_id = '', 
                        env_id = '', 
                        secret_path = '/', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_used = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        is_synced = True, 
                        sync_message = '', 
                        last_sync_job_id = '', 
                        environment = infisicalapi_client.models._api_v1_secret_approvals_get_200_response_approvals_inner_environment._api_v1_secret_approvals_get_200_response_approvals_inner_environment(
                            id = '', 
                            name = '', 
                            slug = '', ), )
                    ],
        )
        """

    def testApiV1WorkspaceWorkspaceIdIntegrationsGet200Response(self):
        """Test ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr
from infisicalapi_client.models.api_v1_secret_approvals_get200_response_approvals_inner_environment import ApiV1SecretApprovalsGet200ResponseApprovalsInnerEnvironment

class ApiV1LdapConfigConfigIdGroupMapsGet200ResponseInner(BaseModel):
    """
    ApiV1LdapConfigConfigIdGroupMapsGet200ResponseInner
    """
    id: StrictStr = Field(...)
    ldap_config_id: StrictStr = Field(default=..., alias="ldapConfigId")
    ldap_group_cn: StrictStr = Field(default=..., alias="ldapGroupCN")
    group: ApiV1SecretApprovalsGet200ResponseApprovalsInnerEnvironment = Field(...)
    __properties = ["id", "ldapConfigId", "ldapGroupCN", "group"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1LdapConfigConfigIdGroupMapsGet200ResponseInner:
        """Create an instance of ApiV1LdapConfigConfigIdGroupMapsGet200ResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of group
        if self.group:
            _dict['group'] = self.group.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1LdapConfigConfigIdGroupMapsGet200ResponseInner:
        """Create an instance of ApiV1LdapConfigConfigIdGroupMapsGet200ResponseInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1LdapConfigConfigIdGroupMapsGet200ResponseInner.parse_obj(obj)

        _obj = ApiV1LdapConfigConfigIdGroupMapsGet200ResponseInner.parse_obj({
            "id": obj.get("id"),
            "ldap_config_id": obj.get("ldapConfigId"),
            "ldap_group_cn": obj.get("ldapGroupCN"),
            "group": ApiV1SecretApprovalsGet200ResponseApprovalsInnerEnvironment.from_dict(obj.get("group")) if obj.get("group") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_integration_integration_id_patch_request import ApiV1IntegrationIntegrationIdPatchRequest  # noqa: E501

class TestApiV1IntegrationIntegrationIdPatchRequest(unittest.TestCase):
    """ApiV1IntegrationIntegrationIdPatchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1IntegrationIntegrationIdPatchRequest:
        """Test ApiV1IntegrationIntegrationIdPatchRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1IntegrationIntegrationIdPatchRequest`
        """
        model = ApiV1IntegrationIntegrationIdPatchRequest()  # noqa: E501
        if include_optional:
            return ApiV1IntegrationIntegrationIdPatchRequest(
                app = '',
                app_id = '',
                is_active = True,
                secret_path = '/',
                target_environment = '',
                owner = '',
                environment = '',
                metadata = infisicalapi_client.models._api_v1_integration__integration_id__patch_request_metadata._api_v1_integration__integrationId__patch_request_metadata(
                    secret_prefix = '', 
                    secret_suffix = '', 
                    initial_sync_behavior = '', 
                    mapping_behavior = 'one-to-one', 
                    should_auto_redeploy = True, 
                    secret_gcp_label = infisicalapi_client.models._api_v1_integration_post_request_metadata_secret_gcp_label._api_v1_integration_post_request_metadata_secretGCPLabel(
                        label_name = '', 
                        label_value = '', ), 
                    secret_aws_tag = [
                        infisicalapi_client.models._api_v1_audit_log_streams__id__get_200_response_audit_log_stream_headers_inner._api_v1_audit_log_streams__id__get_200_response_auditLogStream_headers_inner(
                            key = '', 
                            value = '', )
                        ], 
                    kms_key_id = '', 
                    should_disable_delete = True, 
                    should_enable_delete = True, 
                    should_mask_secrets = True, 
                    should_protect_secrets = True, )
            )
        else:
            return ApiV1IntegrationIntegrationIdPatchRequest(
                is_active = True,
                target_environment = '',
                owner = '',
                environment = '',
        )
        """

    def testApiV1IntegrationIntegrationIdPatchRequest(self):
        """Test ApiV1IntegrationIntegrationIdPatchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, constr

class ApiV1DynamicSecretsPostRequestProviderAnyOf1Inputs(BaseModel):
    """
    ApiV1DynamicSecretsPostRequestProviderAnyOf1Inputs
    """
    host: StrictStr = Field(...)
    port: Union[StrictFloat, StrictInt] = Field(...)
    local_data_center: constr(strict=True, min_length=1) = Field(default=..., alias="localDataCenter")
    keyspace: Optional[StrictStr] = None
    username: StrictStr = Field(...)
    password: StrictStr = Field(...)
    creation_statement: StrictStr = Field(default=..., alias="creationStatement")
    revocation_statement: StrictStr = Field(default=..., alias="revocationStatement")
    renew_statement: Optional[StrictStr] = Field(default=None, alias="renewStatement")
    ca: Optional[StrictStr] = None
    __properties = ["host", "port", "localDataCenter", "keyspace", "username", "password", "creationStatement", "revocationStatement", "renewStatement", "ca"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1DynamicSecretsPostRequestProviderAnyOf1Inputs:
        """Create an instance of ApiV1DynamicSecretsPostRequestProviderAnyOf1Inputs from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1DynamicSecretsPostRequestProviderAnyOf1Inputs:
        """Create an instance of ApiV1DynamicSecretsPostRequestProviderAnyOf1Inputs from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1DynamicSecretsPostRequestProviderAnyOf1Inputs.parse_obj(obj)

        _obj = ApiV1DynamicSecretsPostRequestProviderAnyOf1Inputs.parse_obj({
            "host": obj.get("host"),
            "port": obj.get("port"),
            "local_data_center": obj.get("localDataCenter"),
            "keyspace": obj.get("keyspace"),
            "username": obj.get("username"),
            "password": obj.get("password"),
            "creation_statement": obj.get("creationStatement"),
            "revocation_statement": obj.get("revocationStatement"),
            "renew_statement": obj.get("renewStatement"),
            "ca": obj.get("ca")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_sharing_get200_response import ApiV1SecretSharingGet200Response  # noqa: E501

class TestApiV1SecretSharingGet200Response(unittest.TestCase):
    """ApiV1SecretSharingGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretSharingGet200Response:
        """Test ApiV1SecretSharingGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretSharingGet200Response`
        """
        model = ApiV1SecretSharingGet200Response()  # noqa: E501
        if include_optional:
            return ApiV1SecretSharingGet200Response(
                secrets = [
                    infisicalapi_client.models._api_v1_secret_sharing_get_200_response_secrets_inner._api_v1_secret_sharing_get_200_response_secrets_inner(
                        id = '', 
                        encrypted_value = '', 
                        iv = '', 
                        tag = '', 
                        hashed_hex = '', 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        user_id = '', 
                        org_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires_after_views = 1.337, 
                        access_type = 'anyone', 
                        name = '', 
                        last_viewed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total_count = 1.337
            )
        else:
            return ApiV1SecretSharingGet200Response(
                secrets = [
                    infisicalapi_client.models._api_v1_secret_sharing_get_200_response_secrets_inner._api_v1_secret_sharing_get_200_response_secrets_inner(
                        id = '', 
                        encrypted_value = '', 
                        iv = '', 
                        tag = '', 
                        hashed_hex = '', 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        user_id = '', 
                        org_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires_after_views = 1.337, 
                        access_type = 'anyone', 
                        name = '', 
                        last_viewed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total_count = 1.337,
        )
        """

    def testApiV1SecretSharingGet200Response(self):
        """Test ApiV1SecretSharingGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
